# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.2] 2024-05-28

* Fix bug where `page` data was not available in parent templates.
* Add `pages` variable that can be used to see a list of all pages in a template.
* Small performance improvements.
* Fix missing `click` dependency.

## [0.0.1] 2024-05-27

Initial release of Aurora.
